@@ -1,11 +1,8 @@
 package DateTime::Format::Strptime;
-{
-  $DateTime::Format::Strptime::VERSION = '1.53';
-}
-
+$DateTime::Format::Strptime::VERSION = '1.55';
 use strict;
 
-use DateTime 0.44;
+use DateTime 1.00;
 use DateTime::Locale 0.45;
 use DateTime::TimeZone 0.79;
 use Params::Validate 0.64 qw( validate SCALAR SCALARREF BOOLEAN OBJECT CODEREF );
@@ -275,10 +272,9 @@ sub parse_datetime {
     die $@ if $@;
 
     if ( $self->{diagnostic} ) {
-        print qq|
-
+        my $diag = <<"EOF";
 Entered     = $time_string
-Parser		= $parser
+Parser      = $parser
 
 dow_name    = $dow_name
 month_name  = $month_name
@@ -305,9 +301,14 @@ timezone    = $timezone
 epoch       = $epoch
 iso_week_year     = $iso_week_year
 iso_week_year_100 = $iso_week_year_100
+EOF
 
-		|;
-
+        if ( $ENV{HARNESS_ACTIVE} ) {
+            Test::More::diag($diag);
+        }
+        else {
+            print $diag;
+        }
     }
 
     $self->local_croak("Your datetime does not match your pattern.")
@@ -862,11 +863,11 @@ sub _build_parser {
         '|',
         map      { quotemeta $_ }
             sort { length $b <=> length $a }
-            grep( /\W/, @{ $self->{_locale}->day_format_wide },
-            @{ $self->{_locale}->day_format_abbreviated } )
+            @{ $self->{_locale}->day_format_wide },
+        @{ $self->{_locale}->day_format_abbreviated }
     );
     $day_re .= '|' if $day_re;
-    $regex      =~ s/%a/($day_re\\w+)/gi;
+    $regex =~ s/%a/($day_re\\w+)/gi;
     $field_list =~ s/%a/#dow_name#/gi;
 
     # %a is the day of the week, using the locale's weekday names; either the abbreviated or full name may be specified.
@@ -876,8 +877,8 @@ sub _build_parser {
         '|',
         map      { quotemeta $_ }
             sort { length $b <=> length $a }
-            grep( /\s|\d/, @{ $self->{_locale}->month_format_wide },
-            @{ $self->{_locale}->month_format_abbreviated } )
+            @{ $self->{_locale}->month_format_wide },
+        @{ $self->{_locale}->month_format_abbreviated }
     );
     $month_re .= '|' if $month_re;
     $month_re .= '[^\\s\\d]+';
@@ -995,7 +996,7 @@ sub _build_parser {
 
     # is the year including the century (for example, 1998).
 
-    $regex      =~ s|%z|([+-]\\d{4})|g;
+    $regex      =~ s|%z|([+-]\\d\\d:?\\d\\d)|g;
     $field_list =~ s/%z/#tz_offset#/g;
 
     # Timezone Offset.
@@ -1078,7 +1079,7 @@ DateTime::Format::Strptime - Parse and format strp and strf time patterns
 
 =head1 VERSION
 
-version 1.53
+version 1.55
 
 =head1 SYNOPSIS
 
@@ -1328,7 +1329,8 @@ Arbitrary whitespace.
 
 =item * %N
 
-Nanoseconds. For other sub-second values use C<%[number]N>.
+Nanoseconds. For other sub-second values use C<%[number]N>, where
+C<[number]> is the number of digits (without the brackets).
 
 =item * %p
 
@@ -1391,8 +1393,7 @@ The year, including century (for example, 1991).
 
 =item * %z
 
-An RFC-822/ISO 8601 standard time zone specification. (For example
-+1100) [See note below]
+A time zone offset in the format "[+-]HHmm" or "[+-]HH:mm".
 
 =item * %Z
 
@@ -1442,7 +1443,7 @@ Rick Measham <rickm@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
